==> ejc-budgetmanage-impl-3.0.0-20220330.112743-39-sources.jar: com/ejianc/business/bedget/vo/SubpackageVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.record.vo.RecordsubpackageVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包施工图预算
 * 
 * @author generator
 * 
 */
public class SubpackageVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String remarks; // 备注
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人姓名
    private java.lang.Long contract; // 合同
    private java.lang.String contractName; // 合同名称
    private java.lang.Long subcontractUnit; // 分包单位
    private java.lang.String subcontractUnitName; // 分包单位名称
    private java.math.BigDecimal excludingTaxTotal; // 除税合价合计
    private java.math.BigDecimal includingTaxTotal; // 含税合价合计
    private java.math.BigDecimal excludingTaxUnitPriceTotal; // 除税单价合计
    private java.math.BigDecimal includingTaxUnitPriceTotal; // 含税单价合计



    private List<SubpackagedetailVO> subpackagedetailEntities = new ArrayList<>(); // 分包施工图预算子表
    private List<RecordsubpackageVO> recordsubpackageList = new ArrayList<>(); // 历史信息

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    @ReferDeserialTransfer
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    @ReferDeserialTransfer
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包单位
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public java.lang.Long getSubcontractUnit() {
        return subcontractUnit;
    }

    /**
     * 分包单位
     */
    @ReferDeserialTransfer
    public void setSubcontractUnit(java.lang.Long subcontractUnit) {
        this.subcontractUnit = subcontractUnit;
    }
    /**
     * 分包单位名称
     */
    public java.lang.String getSubcontractUnitName() {
        return subcontractUnitName;
    }

    /**
     * 分包单位名称
     */
    public void setSubcontractUnitName(java.lang.String subcontractUnitName) {
        this.subcontractUnitName = subcontractUnitName;
    }
    /**
     * 除税合价合计
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价合计
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价合计
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价合计
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    /**
     * 除税单价合计
     */
    public java.math.BigDecimal getExcludingTaxUnitPriceTotal() {
        return excludingTaxUnitPriceTotal;
    }

    /**
     * 除税单价合计
     */
    public void setExcludingTaxUnitPriceTotal(java.math.BigDecimal excludingTaxUnitPriceTotal) {
        this.excludingTaxUnitPriceTotal = excludingTaxUnitPriceTotal;
    }
    /**
     * 含税单价合计
     */
    public java.math.BigDecimal getIncludingTaxUnitPriceTotal() {
        return includingTaxUnitPriceTotal;
    }

    /**
     * 含税单价合计
     */
    public void setIncludingTaxUnitPriceTotal(java.math.BigDecimal includingTaxUnitPriceTotal) {
        this.includingTaxUnitPriceTotal = includingTaxUnitPriceTotal;
    }
    /**
     * 分包施工预算图
     */
    public List<SubpackagedetailVO> getSubpackagedetailEntities() {
        return subpackagedetailEntities;
    }

    /**
     * 分包施工预算图
     */
    public void setSubpackagedetailEntities(List<SubpackagedetailVO> subpackagedetailEntities) {
        this.subpackagedetailEntities = subpackagedetailEntities;
    }

    public List<RecordsubpackageVO> getRecordsubpackageList() {
        return recordsubpackageList;
    }

    public void setRecordsubpackageList(List<RecordsubpackageVO> recordsubpackageList) {
        this.recordsubpackageList = recordsubpackageList;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/bedget/vo/SubpackageVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.record.vo.RecordsubpackageVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包施工图预算
 * 
 * @author generator
 * 
 */
public class SubpackageVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String remarks; // 备注
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人姓名
    private java.lang.Long contract; // 合同
    private java.lang.String contractName; // 合同名称
    private java.lang.Long subcontractUnit; // 分包单位
    private java.lang.String subcontractUnitName; // 分包单位名称
    private java.math.BigDecimal excludingTaxTotal; // 除税合价合计
    private java.math.BigDecimal includingTaxTotal; // 含税合价合计
    private java.math.BigDecimal excludingTaxUnitPriceTotal; // 除税单价合计
    private java.math.BigDecimal includingTaxUnitPriceTotal; // 含税单价合计

    private java.lang.String createTimeShow; // 创建时间文本显示
    private java.lang.String billStateStr; // 单据状态文本显示
    private java.lang.String sort; // 序号

    private java.lang.Long isEnable; //是否开启控制

    private List<SubpackagedetailVO> subpackagedetailEntities = new ArrayList<>(); // 分包施工图预算子表
    private List<RecordsubpackageVO> recordsubpackageList = new ArrayList<>(); // 历史信息

    public Long getIsEnable() {
        return isEnable;
    }

    public void setIsEnable(Long isEnable) {
        this.isEnable = isEnable;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    @ReferDeserialTransfer
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    @ReferDeserialTransfer
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包单位
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public java.lang.Long getSubcontractUnit() {
        return subcontractUnit;
    }

    /**
     * 分包单位
     */
    @ReferDeserialTransfer
    public void setSubcontractUnit(java.lang.Long subcontractUnit) {
        this.subcontractUnit = subcontractUnit;
    }
    /**
     * 分包单位名称
     */
    public java.lang.String getSubcontractUnitName() {
        return subcontractUnitName;
    }

    /**
     * 分包单位名称
     */
    public void setSubcontractUnitName(java.lang.String subcontractUnitName) {
        this.subcontractUnitName = subcontractUnitName;
    }
    /**
     * 除税合价合计
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价合计
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价合计
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价合计
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    /**
     * 除税单价合计
     */
    public java.math.BigDecimal getExcludingTaxUnitPriceTotal() {
        return excludingTaxUnitPriceTotal;
    }

    /**
     * 除税单价合计
     */
    public void setExcludingTaxUnitPriceTotal(java.math.BigDecimal excludingTaxUnitPriceTotal) {
        this.excludingTaxUnitPriceTotal = excludingTaxUnitPriceTotal;
    }
    /**
     * 含税单价合计
     */
    public java.math.BigDecimal getIncludingTaxUnitPriceTotal() {
        return includingTaxUnitPriceTotal;
    }

    /**
     * 含税单价合计
     */
    public void setIncludingTaxUnitPriceTotal(java.math.BigDecimal includingTaxUnitPriceTotal) {
        this.includingTaxUnitPriceTotal = includingTaxUnitPriceTotal;
    }
    /**
     * 分包施工预算图
     */
    public List<SubpackagedetailVO> getSubpackagedetailEntities() {
        return subpackagedetailEntities;
    }

    /**
     * 分包施工预算图
     */
    public void setSubpackagedetailEntities(List<SubpackagedetailVO> subpackagedetailEntities) {
        this.subpackagedetailEntities = subpackagedetailEntities;
    }

    public List<RecordsubpackageVO> getRecordsubpackageList() {
        return recordsubpackageList;
    }

    public void setRecordsubpackageList(List<RecordsubpackageVO> recordsubpackageList) {
        this.recordsubpackageList = recordsubpackageList;
    }
}
